unit uPlugin;
{$INCLUDE 'Plugin.inc'}

interface

implementation

uses
  Windows, SysUtils, Classes,
  {$INCLUDE 'DelphiFarUnits.inc'} ,
  {$IFDEF DEBUG_LOGS} uLog, {$ENDIF}
  uOptions, uOptionsUI,
  uMessages, uEditorTasks, uPluginConsts;

type
  TPlugin = class(TFarPlugin)
  private
    fOptions: TOptions;
    function GetOptions: TOptions;
  protected
    function PluginID: TGUID; override;
    function GetPluginTitle(out Description, Author: string): string; override;
    procedure GetPluginInfo(var Flags: TPluginFlags; var MainMenu, ConfigMenu, DiskMenu: TFarPlugin.TFarPluginMenu; var CommandPrefix: string); override;
    function GetCommonString(ID: TFarPlugin.TCommonString): string; override;
    function Execute(OpenFrom: DWORD; GUID: PGUID; Data: TIntPtr): THandle; override;
    function PluginConfig(GUID: PGUID; MenuItem: TIntPtr): boolean; override;
    function ProcessMacroCall(const Params: array of Variant): boolean;
    procedure DoLog(const Msg: string); override;
    procedure RefreshOptions;
    property Options: TOptions read GetOptions;
  public
    constructor Create;
    destructor Destroy; override;
  end;

const
  PLUGIN_TITLE = 'FarCtags';
  PLUGIN_DESCRIPTION = 'FAR Ctags';
  PLUGIN_AUTHOR = 'Pepak, https://www.pepak.net';

{ TPlugin }

constructor TPlugin.Create;
begin
  inherited;
  fOptions := nil;
end;

destructor TPlugin.Destroy;
begin
  FreeAndNil(fOptions);
  inherited;
end;

procedure TPlugin.DoLog(const Msg: string);
begin
  {$IFDEF DEBUG_LOGS}
  uLog.Log(Msg);
  {$ENDIF}
end;

function TPlugin.Execute(OpenFrom: DWORD; GUID: PGUID; Data: TIntPtr): THandle;
var
  Tasks: TEditorTasks;
begin
  Result := {$IFDEF FAR3_UP} 0 {$ELSE} INVALID_HANDLE_VALUE {$ENDIF} ;
  RefreshOptions;
  {$IFDEF FAR3_UP}
  if OpenFrom = OPEN_FROMMACRO_ then
  begin
    if ProcessMacroCall(TFarMacro.MacroParamsToDelphi(Data)) then
      Result := 1;
  end;
  {$ENDIF}
  if OpenFrom = OPEN_EDITOR then
  begin
    Tasks := TEditorTasks.Create;
    try
      Tasks.EditorID := -1;
      Tasks.Execute;
    finally
      FreeAndNil(Tasks);
    end;
  end;
end;

function TPlugin.GetCommonString(ID: TFarPlugin.TCommonString): string;
begin
  case ID of
    TFarPlugin.TCommonString.MTitle:
      Result := GetMsg(MTitle);
    TFarPlugin.TCommonString.MExceptionOccurredIn:
      Result := GetMsg(MExceptionOccurredIn);
    TFarPlugin.TCommonString.MOk:
      Result := GetMsg(MOk);
    TFarPlugin.TCommonString.MCancel:
      Result := GetMsg(MCancel);
    TFarPlugin.TCommonString.MYes:
      Result := GetMsg(MYes);
    TFarPlugin.TCommonString.MNo:
      Result := GetMsg(MNo);
    else
      Result := inherited GetCommonString(ID);
  end;
end;

function TPlugin.GetOptions: TOptions;
begin
  if fOptions = nil then
  begin
    fOptions := TOptions.Create;
    fOptions.Load;
  end;
  Result := fOptions;
end;

procedure TPlugin.GetPluginInfo(var Flags: TPluginFlags; var MainMenu, ConfigMenu, DiskMenu: TFarPlugin.TFarPluginMenu; var CommandPrefix: string);
begin
  Flags := Flags or PF_EDITOR or PF_DISABLEPANELS;
  SetLength(MainMenu, 1);
  MainMenu[0].Title := GetMsg(MTitle);
  MainMenu[0].ID := MENU_PANEL_GUID;
  SetLength(ConfigMenu, 1);
  ConfigMenu[0].Title := GetMsg(MTitle);
  ConfigMenu[0].ID := MENU_OPTIONS_GUID;
end;

function TPlugin.GetPluginTitle(out Description, Author: string): string;
begin
  Result := PLUGIN_TITLE;
  Description := PLUGIN_DESCRIPTION;
  Author := PLUGIN_AUTHOR;
end;

function TPlugin.PluginConfig(GUID: PGUID; MenuItem: TIntPtr): boolean;
var
  Dialog: TOptionsDialog;
begin
  Result := False;
  RefreshOptions;
  Dialog := TOptionsDialog.Create;
  try
    Dialog.Options := Options;
    if Dialog.Execute then
    begin
      Options.Save;
      Result := True;
    end;
  finally
    FreeAndNil(Dialog);
  end;
end;

function TPlugin.PluginID: TGUID;
begin
  Result := PLUGIN_GUID;
end;

function TPlugin.ProcessMacroCall(const Params: array of Variant): boolean;
var
  FunctionName: string;
  Tasks: TEditorTasks;
begin
  Result := False;
  if Length(Params) > 0 then
  begin
    FunctionName := Params[0];
    if FunctionName = 'execute' then
    begin
      Tasks := TEditorTasks.Create;
      try
        Tasks.EditorID := -1;
        if Tasks.Execute then
          Result := True;
      finally
        FreeAndNil(Tasks);
      end;
      Exit;
    end;
  end;
end;

procedure TPlugin.RefreshOptions;
begin
  FreeAndNil(fOptions);
end;

initialization
  TFarPlugin.InitInstance(TPlugin.Create);

end.
